@@ -28,7 +28,7 @@ class TestTicketFolder(BaseTestCase):
             get_remotely_changed.return_value = []
             self.ticketfolder = run_command_method_with_kwargs(
                 'clone',
-                ticket_url='http://arbitrary.com/browse/ALPHA-123',
+                url='http://arbitrary.com/browse/ALPHA-123',
                 jira=self.mock_get_jira,
                 path=os.path.join(
                     self.root_folder,
